from __future__ import absolute_import, division, print_function

import os

import fintecture


print("Searching URL to connect with AIS...")

redirect_uri = 'https://webhook.site/5940c656-7fd3-40a0-ad41-9cfba1e986f3'

resp = fintecture.AIS.connect(
    app_id=os.environ.get("FINTECTURE_APP_ID"),
    redirect_uri=redirect_uri,
    state="1234"
)

print("Redirecting user to {} ...".format(
    resp['meta']['url']
))
print("Success: %r" % (resp))


# after connecting with above URL we receive data from webhook as bellow
# customer_id	    1bfca013fedeb208080c5bead11df5ca
# code	            56f0533637c1aa1eff0fd2bf5d6f9fce
# provider	        cmcifrpp
# state	            1234



# File generated from our OpenAPI spec
from __future__ import absolute_import, division, print_function

from fintecture import util
from fintecture.api_resources.abstract import CreateableAPIResource
from fintecture.api_resources.abstract import DeletableAPIResource
from fintecture.api_resources.abstract import ListableAPIResource


class TestClock(
    CreateableAPIResource,
    DeletableAPIResource,
    ListableAPIResource,
):
    OBJECT_NAME = "test_helpers.test_clock"

    @classmethod
    def _cls_advance(
        cls,
        test_clock,
        api_key=None,
        fintecture_version=None,
        fintecture_account=None,
        **params
    ):
        return cls._static_request(
            "post",
            "/v1/test_helpers/test_clocks/{test_clock}/advance".format(
                test_clock=util.sanitize_id(test_clock)
            ),
            api_key=api_key,
            fintecture_version=fintecture_version,
            fintecture_account=fintecture_account,
            params=params,
        )

    @util.class_method_variant("_cls_advance")
    def advance(self, idempotency_key=None, **params):
        return self._request(
            "post",
            "/v1/test_helpers/test_clocks/{test_clock}/advance".format(
                test_clock=util.sanitize_id(self.get("id"))
            ),
            idempotency_key=idempotency_key,
            params=params,
        )



from __future__ import absolute_import, division, print_function

import fintecture


TEST_RESOURCE_ID = "vs_123"


class TestVerificationReport(object):
    def test_is_listable(self, request_mock):
        resources = fintecture.identity.VerificationReport.list()
        request_mock.assert_requested(
            "get", "/v1/identity/verification_reports"
        )
        assert isinstance(resources.data, list)
        assert isinstance(
            resources.data[0], fintecture.identity.VerificationReport
        )

    def test_is_retrievable(self, request_mock):
        resource = fintecture.identity.VerificationReport.retrieve(
            TEST_RESOURCE_ID
        )
        request_mock.assert_requested(
            "get", "/v1/identity/verification_reports/%s" % TEST_RESOURCE_ID
        )
        assert isinstance(resource, fintecture.identity.VerificationReport)
